@@ -17,21 +17,18 @@
 """Decorator helpers that simplify class composition."""
 
 __all__ = [
+    'Passthrough',
     'delegate_to',
     ]
 
+try:
+    import importlib.metadata as importlib_metadata
+except ImportError:  # pragma: no cover
+    import importlib_metadata
 
-from lazr.delegates._version import __version__
-__version__
+from lazr.delegates._delegates import (
+    Passthrough,
+    delegate_to,
+    )
 
-from lazr.delegates._passthrough import Passthrough
-
-# The class decorator syntax is different in Python 2 vs. Python 3.
-import sys
-if sys.version_info[0] == 2:
-    from lazr.delegates._python2 import delegate_to
-    # The legacy API is only compatible with Python 2.
-    from lazr.delegates._delegates import delegates
-    __all__.append('delegates')
-else:
-    from lazr.delegates._python3 import delegate_to
+__version__ = importlib_metadata.version("lazr.delegates")
